import requests
import jwt
import tempfile
import json
from os import path
from django.conf import settings
from django_client_sso.exceptions import Exception401

class ClientBase():
    
    def __init__(self) -> None:
        self.host = settings.SSO_HOST
        self.client = settings.CLIENT_ID
        self.secret = settings.CLIENT_SECRET

    def get_app_token(self):
        data = {
            'client_id':self.client,
            'client_secret':self.secret,
            'grant_type':'client_credentials'
        }
        response = requests.post(f'{self.host}/o/token/',data=data)
        
        if response.status_code != 200:
            raise Exception(f'Erro ao tentar conectar no servidor sso. cod:{response.status_code}')
        
        content = response.content.decode('utf-8')
        content = json.loads(content)
        
        return content['access_token']
   
    def get_pub(self):
        if path.exists(f'{tempfile.gettempdir()}/sso.pub'):
            return        
        
        app_token = self.get_app_token()
        headers = {
            'Authorization':f'Bearer {app_token}'
        }        
        response = requests.get(f'{self.host}/pub/',headers=headers)
        content = response.content.decode('utf-8')
        content = json.loads(content)
        
        with open(f'{tempfile.gettempdir()}/sso.pub','w') as file:
            file.write(content['data'])
            file.close()
            
        
    def decode_token(self,token:str):
        self.get_pub()
        publib_key = open(f'{tempfile.gettempdir()}/sso.pub','r').read()        
        try:
            return jwt.decode(token,key=publib_key,algorithms=['RS256'])    
        except:
            raise Exception401()


from setuptools import setup

setup(
    name='django-sso-client',
    version='0.0.8',
    author='TIT CS',
    author_email='contato@titcs.com.br',
    packages=['django_client_sso'],
    description='Client for Django Apps - SSO TIT/Hyper by P&D',
    long_description='Client for Django Apps - SSO TIT/Hyper by P&D',
    url='https://TITBrasil@dev.azure.com/TITBrasil/TITCS%20-%20Live4Safe/_git/DJANGO_CLIENT',
    project_urls={
        'Código fonte': 'https://TITBrasil@dev.azure.com/TITBrasil/Gamefica/_git/DJANGO_CLIENT',
        'Download': 'https://TITBrasil@dev.azure.com/TITBrasil/Gamefica/_git/DJANGO_CLIENT'
    },
    license='MIT',
    keywords='django_client_sso',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: Portuguese (Brazilian)',
        'Operating System :: OS Independent',
        'Topic :: Software Development :: Internationalization',
        'Topic :: Scientific/Engineering :: Physics'
    ]
)



from django.http import HttpResponseRedirect
from django_client_sso.client_base import ClientBase
import requests

class ClientOffice365(ClientBase):

    def login(self):
        response =  requests.get(
            url=f'{self.host}/office365/login/',
            headers={'Authorization': f'Bearer {self.get_app_token()}'}
        )
        return HttpResponseRedirect(response.url)